@@ -2,7 +2,7 @@
 #### alfa-regression
 #### Tsagris Michail 11/2015
 #### mtsagris@yahoo.gr
-#### References: Tsagris Michail (2013)
+#### References: Tsagris Michail (2015)
 #### Regression analysis with compositional data containing zero values
 #### Chilean Journal of Statistics, 6(2): 47-57
 ################################
@@ -11,10 +11,9 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
   ## x is the independent variables
   ## a is the value of alpha
   ## internal function for the alfa-regression
-  reg <- function(para, ya, x, a, ha, d, D) {
+  reg <- function(para, ya, ax, a, ha, d, D) {
     be <- matrix(para, ncol = d)
-    mu1 <- cbind( 1, exp(x %*% be) )
-    zz <- mu1^a
+    zz <- cbind( 1, exp(ax %*% be) )
     ta <- rowSums(zz)
     za <- zz / ta
     ma <- ( D / a * za - 1/a ) %*% ha
@@ -25,6 +24,7 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
     ya <- Compositional::alfa(y, a)$aff
   } else  ya <- yb
   x <- model.matrix(ya ~., data.frame(x) )
+  ax <- a * x
 
   D <- dim(y)[2]
   d <- D - 1  ## dimensionality of the simplex
@@ -37,15 +37,14 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
 
   } else {
     runtime <- proc.time()
-
     ha <- t( helm(D) )
     ini <- as.vector( solve(crossprod(x), crossprod(x, ya) ) )
-    qa1 <- nlminb( ini, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(iter.max = 5000) )
-    qa1 <- optim( qa1$par, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000) )
-    qa2 <- optim( qa1$par, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000) )
+    qa1 <- nlminb( ini, reg, ya = ya, ax = ax, a = a, ha = ha, d = d, D = D, control = list(iter.max = 5000) )
+    qa1 <- optim( qa1$par, reg, ya = ya, ax = ax, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000) )
+    qa2 <- optim( qa1$par, reg, ya = ya, ax = ax, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000) )
     while (qa1$value - qa2$value > 1e-04) {
       qa1 <- qa2
-      qa2 <- optim( qa1$par, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000), hessian = TRUE )
+      qa2 <- optim( qa1$par, reg, ya = ya, ax = ax, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000), hessian = TRUE )
     }
     be <- matrix(qa2$par, ncol = d)
     runtime <- proc.time() - runtime
