@@ -26,12 +26,12 @@ ice.pprcomp <- function(model, x, k = 1, frac = 0.1, type = "log") {
   nam <- colnames(x)[k]
   if ( is.null(nam) )  nam <- paste("Variable ", k, sep = "")
 
-  est <- est[-1, ] - est[1, ]
-  plot( xsel, est[1, ], type = "l", xlab = nam, ylab = "Centered fitted values",
+  est <- est[, -1] - est[, 1]
+  plot( xsel[-1], est[1, ], type = "l", xlab = nam, ylab = "Centered fitted values",
         cex.lab = 1.3, cex.axis = 1.3, ylim = c( min(est), max(est) ) )
   abline(v = seq( min(xsel), max(xsel), length = 10 ), col = "lightgrey", lty = 2)
   abline(h = seq(min(est), max(est), length = 10), col = "lightgrey", lty = 2)
-  for (i in 2:c(n - 1) )  lines(xsel, est[i, ])
+  for (i in 2:n )  lines(xsel[-1], est[i, ])
   m <- Rfast::colmeans(est)
-  lines(xsel, m, col = 4, lwd = 3)
+  lines(xsel[-1], m, col = 4, lwd = 3)
 }
